var sqlite3 = require('sqlite3').verbose();
var mode = sqlite3.OPEN_READWRITE | sqlite3.OPEN_CREATE;
var http = require('http');

function runTest(req, res) {
  res.writeHead(200, {'Content-Type': 'text/plain'});

  var db = new sqlite3.Database(__dirname + '/blog.db', mode, function(dberror) {
    if (dberror != null) { 
      console.log(dberror); 
    } else {
      checkTableExists(db, 'lorem1', function (err, exists) {
        if (err != null) { 
          console.log(err); 
        } else {
          if (!exists) {
            createDbTable(db, function() {
              res.write('Created Database table lorem1...');
              insertTestDate(db, function() {
                getRecords(db, function() {
                  res.end('Hello World\nGot records for tinyblog...');
                });
              });
            });
          } else {
            getRecords(db, function() {
              res.end('Hello World\nGot records for tinyblog...');
            });
          }
        }
      });
      
    }
  });
}

function insertTestDate(db, callback) {
  db.serialize(function() {
    var stmt = db.prepare("INSERT INTO lorem1 VALUES (?)");
    for (var i = 0; i < 10; i++) {
        stmt.run("Ipsum " + i);
    }
    stmt.finalize();
  });
  callback();
}

function createDbTable(db, callback) {
  db.run("CREATE TABLE lorem1 (info TEXT)", function () {
    callback();
  });
}

function getRecords(db, callback) {
  db.each("SELECT rowid, info FROM lorem1", function(queryerror, row) {
    if (queryerror != null) {
      console.log(queryerror); 
    } else {
      console.log(row.rowid + ": " + row.info);
    }         
  }, function() {
    callback();
  });
}

//Call back returns a err and then true or false 
function checkTableExists(db, tablename, callback) {
  try {
    var sql = "SELECT name FROM sqlite_master WHERE type='table' AND name=?";
    db.all(sql, tablename, function(queryerror, rows) {
      if (rows.length <= 0) {
        callback(null, false);
      } else {
        callback(null, true);
      }
    });
  } catch (err) {
    callback(err, false);
  }
}
